Struct ActiveLow
Other items inswitch_hal
pub struct ActiveLow;
Zero sized struct for signaling to Switch that it is active low
impl Send for ActiveLow
impl Sync for ActiveLow
impl Unpin for ActiveLow
impl<T> Any for T where T: 'static + ?Sized,
pub fn type_id(&self) -> TypeId
Gets the TypeId of self. Read more
TypeId
self
impl<T> Borrow<T> for T where T: ?Sized,
pub fn borrow(&self) -> &T
Immutably borrows from an owned value. Read more
impl<T> BorrowMut<T> for T where T: ?Sized,
pub fn borrow_mut(&mut self) -> &mut T
Mutably borrows from an owned value. Read more
impl<T> From<T> for T
pub fn from(t: T) -> T
Performs the conversion.
impl<T, U> Into<U> for T where U: From<T>,
pub fn into(self) -> U
impl<T> IntoSwitch for T
pub fn into_switch<ActiveLevel>(Self) -> Switch<T, ActiveLevel>
Consumes the IoPin returning a Switch of the appropriate ActiveLevel. Read more
IoPin
ActiveLevel
fn into_active_low_switch(self) -> Switch<Self, ActiveLow> where Self: Sized,
Consumes the IoPin returning a Switch<IoPin, ActiveLow>. Read more
Switch<IoPin, ActiveLow>
fn into_active_high_switch(self) -> Switch<Self, ActiveHigh> where Self: Sized,
Consumes the IoPin returning a Switch<IoPin, ActiveHigh>. Read more
Switch<IoPin, ActiveHigh>
impl<T, U> TryFrom<U> for T where U: Into<T>,
type Error = Infallible
The type returned in the event of a conversion error.
pub fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto<U> for T where U: TryFrom<T>,
type Error = <U as TryFrom<T>>::Error
pub fn try_into(self) -> Result<U, <U as TryFrom<T>>::Error>